/* stylelint-disable docusaurus/copyright-header */
/**
 * Any CSS included here will be global. The classic template
 * bundles Infima by default. Infima is a CSS framework designed to
 * work well for content-centric websites.
 */

/* You can override the default Infima variables here. */
:root {
  --ifm-color-primary: #0098CC;
  --ifm-color-primary-dark: #0076AF;
  --ifm-color-primary-darker: #005892;
  --ifm-color-primary-darkest: #003F76;
  --ifm-color-primary-light: #38C1E0;
  --ifm-color-primary-lighter: #5FDFEF;
  --ifm-color-primary-lightest: #95F5F9;

  --ifm-color-secondary: #CACAD2;
  --ifm-color-secondary-dark: #9F9FAC;
  --ifm-color-secondary-darker: #9F9FAC;
  --ifm-color-secondary-darkest: #666675;
  --ifm-color-secondary-light: #E9E9F0;
  --ifm-color-secondary-lighter: #F4F4F7;
  --ifm-color-secondary-lightest: #F4F4F7;

  --ifm-color-warning: #FF970F;
  --ifm-color-warning-dark: #DB770A;
  --ifm-color-warning-darker: #B75B07;
  --ifm-color-warning-darkest: #934304;
  --ifm-color-warning-light: #FFB84B;
  --ifm-color-warning-lighter: #FFCD6F;
  --ifm-color-warning-lightest: #FFE29F;
  --ifm-code-font-size: 95%;
}

.docusaurus-highlight-code-line {
  background-color: rgba(0, 0, 0, 0.1);
  display: block;
  margin: 0 calc(-1 * var(--ifm-pre-padding));
  padding: 0 var(--ifm-pre-padding);
}

.alert {
  background-color: var(--ifm-alert-background-color)!important;
}

html[data-theme='dark'] .docusaurus-highlight-code-line {
  background-color: rgba(0, 0, 0, 0.3);
}

html[data-theme='dark'] .prism-code {
  background-color: rgb(45, 51, 59)!important;
}

html[data-theme='dark'] main img[src$=".png"] {
  background-color:white;
}


html[data-theme='dark'] {
  --ifm-background-color: rgb(34, 39, 46);
  --ifm-color-primary:#0098cc;

  --ifm-navbar-background-color: rgb(45, 51, 59)
}

html[data-theme='dark'] .footer--dark {
  background-color: rgb(45, 51, 59);
}

.navbar__brand img {
  width: 75px;
  height: auto;
}
